package cz.filipnovak.wntr.domain;

import cz.filipnovak.wntr.enumeration.PermissionEnum;
import cz.filipnovak.wntr.enumeration.RoleEnum;
import cz.filipnovak.wntr.utility.SecurityUtil;
import cz.filipnovak.wntr.utility.StringUtil;

import javax.persistence.*;
import java.util.Collection;
import java.util.Set;

@Entity
public class User {

    @Id
    @GeneratedValue
    private Long id;

    private boolean deleted;

    private String username;
    private String passwordHash;

    private String name;

    @ManyToOne
    private Organization organization;

    @ManyToOne
    private Facility facility;

    @ElementCollection
    @Enumerated(EnumType.STRING)
    private Set<RoleEnum> roles;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public boolean isDeleted() {
        return deleted;
    }

    public void setDeleted(boolean deleted) {
        this.deleted = deleted;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getPasswordHash() {
        return passwordHash;
    }

    public void setPasswordHash(String passwordHash) {
        this.passwordHash = passwordHash;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Organization getOrganization() {
        return organization;
    }

    public void setOrganization(Organization organization) {
        this.organization = organization;
    }

    public Facility getFacility() {
        return facility;
    }

    public void setFacility(Facility facility) {
        this.facility = facility;
    }

    public Set<RoleEnum> getRoles() {
        return roles;
    }

    public void setRoles(Set<RoleEnum> roles) {
        this.roles = roles;
    }

    @Override
    public String toString() {
        return StringUtil.toString(
                this.getClass(),
                "id=" + id,
                "username=" + username,
                "roles=" + roles
        );
    }

    public boolean hasPermission(PermissionEnum permission) {
        return roles.stream()
                .map(RoleEnum::getPermissions)
                .flatMap(Collection::stream)
                .anyMatch(p -> p.equals(permission));
    }

    public boolean isAnonymous() {
        return SecurityUtil.ANONYMOUS_USER.equals(username);
    }
}
