package cz.filipnovak.wntr.repository;

import cz.filipnovak.wntr.domain.Counter;
import cz.filipnovak.wntr.domain.CounterUpdate;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.CrudRepository;
import org.springframework.stereotype.Repository;

import javax.persistence.ColumnResult;
import javax.persistence.ConstructorResult;
import javax.persistence.SqlResultSetMapping;
import javax.persistence.Tuple;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

@SqlResultSetMapping(
        name = "findDailyLastOccupancyByCounter",
        classes = {
                @ConstructorResult(
                        targetClass = OccupancyByDate.class,
                        columns = {
                                @ColumnResult( name = "occupancy", type = String.class),
                                @ColumnResult( name = "d", type = LocalDate.class)
                        }
                )
        }
)
@Repository
public interface CounterUpdateRepository extends CrudRepository<CounterUpdate, Long> {

    CounterUpdate findByCounterAndStamp(Counter counter, String stamp);

    @Query("SELECT NEW cz.filipnovak.wntr.repository.OccupancyByDate(MAX(cu.occupancy), CAST(cu.timeStamp AS LocalDate)) FROM CounterUpdate cu WHERE cu.counter = :counter GROUP BY CAST(cu.timeStamp as LocalDate)")
    List<OccupancyByDate> findDailyMaxOccupancyByCounter(Counter counter);

    @Query(
            value =
                    "SELECT cu.occupancy occupancy, mt.d date FROM counter_update cu " +
                    "INNER JOIN ( " +
                    "    SELECT counter_id, CAST(time_stamp AS DATE) d, MAX(time_stamp) m FROM counter_update " +
                    "    WHERE counter_id = :counterId " +
                    "    GROUP BY counter_id, CAST(time_stamp AS DATE)" +
                    ") mt ON mt.m = cu.time_stamp AND mt.counter_id = cu.counter_id",
            nativeQuery = true
    )
    List<Tuple> findDailyLastOccupancyByCounter(Long counterId);

    @Query(
            value =
                    "SELECT occupancy FROM counter_update " +
                    "WHERE counter_id = :counterId AND time_stamp < :date " +
                    "ORDER BY time_stamp DESC " +
                    "LIMIT 1",
            nativeQuery = true
    )
    Integer findLastOccupancyBeforeDateByCounter(Long counterId, LocalDate date);

    @Query("SELECT CAST(MIN(timeStamp) AS LocalDate) FROM CounterUpdate")
    LocalDate findOldestDate();

    @Query("SELECT CAST(MAX(timeStamp) AS LocalDateTime) FROM CounterUpdate WHERE counter = :counter")
    LocalDateTime findNewestTime(Counter counter);
}
