package cz.filipnovak.wntr.responsedto;

import cz.filipnovak.wntr.domain.User;
import cz.filipnovak.wntr.enumeration.RoleEnum;
import cz.filipnovak.wntr.utility.SecurityUtil;

import java.util.Collection;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

public class CurrentUserDto extends AbstractResponseDto {
    private final String username;
    private final Boolean authenticated;

    private final Map<String, String> permissions;

    public CurrentUserDto(User user) {
        super("OK");

        username = user != null ? user.getUsername() : null;
        authenticated = user != null && !SecurityUtil.ANONYMOUS_USER.equals(user.getUsername());

        permissions = user.getRoles()
                .stream()
                .map(RoleEnum::getPermissions)
                .flatMap(Collection::stream)
                .map(Enum::name)
                .collect(Collectors.toMap(
                        Function.identity(),
                        Function.identity(),
                        (r1, r2) -> r1
                ));
    }

    public String getUsername() {
        return username;
    }

    public Boolean getAuthenticated() {
        return authenticated;
    }

    public Map<String, String> getPermissions() {
        return permissions;
    }
}
