package cz.filipnovak.wntr.rest;

import cz.filipnovak.wntr.domain.User;
import cz.filipnovak.wntr.responsedto.CurrentUserDto;
import cz.filipnovak.wntr.dto.LoginDto;
import cz.filipnovak.wntr.service.SecurityService;
import cz.filipnovak.wntr.service.UserService;
import cz.filipnovak.wntr.utility.SecurityUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/api/authentication")
public class AuthenticationRestController {

    @Autowired
    private UserService userService;

    @Autowired
    private SecurityService securityService;

    @PostMapping("/login")
    public ResponseEntity<CurrentUserDto> login(@RequestBody LoginDto loginDto) {
        User user = userService.findUserByNameAndPassword(loginDto.getUsername(), loginDto.getPassword());

        // it would fail on wrong credentials before
        SecurityUtil.setUsername(user.getUsername());
        loginDto.setAuthenticated(true);

        return getCurrentUser();
    }

    @GetMapping("/logout")
    public ResponseEntity<CurrentUserDto> logout() {
        SecurityUtil.setUsername(null);

        LoginDto loginDto = new LoginDto();
        loginDto.setAuthenticated(false);

        return getCurrentUser();
    }

    @GetMapping("/me")
    public ResponseEntity<CurrentUserDto> me() {
        return getCurrentUser();
    }

    private ResponseEntity<CurrentUserDto> getCurrentUser() {
        User user = userService.findCurrentUser();

        CurrentUserDto response = new CurrentUserDto(user);
        return ResponseEntity.ok(response);
    }
}
