package cz.filipnovak.wntr.rest;

import cz.filipnovak.wntr.domain.ChatConversation;
import cz.filipnovak.wntr.dto.ConversationDto;
import cz.filipnovak.wntr.dto.PostMessageDto;
import cz.filipnovak.wntr.mapper.ChatMessageMapper;
import cz.filipnovak.wntr.responsedto.ChatMessageDto;
import cz.filipnovak.wntr.responsedto.OkResponseDto;
import cz.filipnovak.wntr.service.ChatService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.stream.Collectors;

@RestController
@RequestMapping("/api/chat")
public class ChatRestController {

    @Autowired
    ChatService chatService;

    @GetMapping("/conversation/list")
    public ResponseEntity<List<ChatConversation>> listConversations() {
        return ResponseEntity.ok(
                chatService.listConversations()
        );
    }

    @PostMapping("/conversation/start")
    @CrossOrigin("*")
    public ResponseEntity<ChatConversation> startConversation(@RequestBody ConversationDto conversation) {
        return ResponseEntity.ok(
                chatService.startConversation(conversation)
        );
    }

    @PostMapping("/conversation/close")
    public ResponseEntity<OkResponseDto> closeConversation(@RequestParam Long conversationId) {
        chatService.closeConversation(conversationId);
        return ResponseEntity.ok(new OkResponseDto());
    }

    @PostMapping("/message/list")
    @CrossOrigin("*")
    public ResponseEntity<List<ChatMessageDto>> listMessages(@RequestBody ConversationDto conversation) {
        return ResponseEntity.ok(
                chatService
                        .listMessages(conversation)
                        .stream()
                        .map(ChatMessageMapper::toDto)
                        .collect(Collectors.toList())
        );
    }

    @PostMapping("/message/question")
    @CrossOrigin("*")
    public ResponseEntity<OkResponseDto> postQuestion(@RequestBody PostMessageDto postMessage) {
        chatService.postQuestion(postMessage);
        return ResponseEntity.ok(new OkResponseDto());
    }

    @PostMapping("/message/answer")
    public ResponseEntity<OkResponseDto> postAnswer(@RequestBody PostMessageDto postMessage) {
        chatService.postAnswer(postMessage);
        return ResponseEntity.ok(new OkResponseDto());
    }
}
