package cz.filipnovak.wntr.rest;

import cz.filipnovak.wntr.responsedto.ErrorResponseDto;
import cz.filipnovak.wntr.exception.ValidationException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;

@ControllerAdvice
public class ExceptionRestController {

    private Logger logger = LoggerFactory.getLogger(ExceptionRestController.class);

    @ExceptionHandler(ValidationException.class)
    public ResponseEntity<Object> validationException(ValidationException vax) {
        return logAndCreateResponse(vax, vax.getType().name(), vax.getMessage(), HttpStatus.INTERNAL_SERVER_ERROR);
    }

    @ExceptionHandler(SecurityException.class)
    public ResponseEntity<Object> securityException(SecurityException sex) {
        return logAndCreateResponse(sex, "SECURITY_ERROR", "REST call security error", HttpStatus.UNAUTHORIZED);
    }

    @ExceptionHandler(Exception.class)
    public ResponseEntity<Object> exception(Exception ex) {
        return logAndCreateResponse(ex, "INTERNAL_ERROR", "Internal server error", HttpStatus.INTERNAL_SERVER_ERROR);
    }

    private ResponseEntity<Object> logAndCreateResponse(Exception ex, String code, String message, HttpStatus status) {
        if (message == null) {
            message = code;
        }

        logger.error(message, ex);
        return new ResponseEntity<>(new ErrorResponseDto(code, message), status);
    }
}
