package cz.filipnovak.wntr.rest;

import cz.filipnovak.wntr.domain.Facility;
import cz.filipnovak.wntr.dto.OccupancyUpdateDto;
import cz.filipnovak.wntr.mapper.FacilityMapper;
import cz.filipnovak.wntr.responsedto.CurrentFacilityDto;
import cz.filipnovak.wntr.responsedto.OkResponseDto;
import cz.filipnovak.wntr.service.FacilityService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api/facility")
public class FacilityRestController {

    @Autowired
    FacilityService facilityService;

    @GetMapping("/list")
    @CrossOrigin("*")
    public ResponseEntity<List<Facility>> getFacilities() {
        return ResponseEntity.ok(facilityService.findAll());
    }

    @GetMapping("/get")
    @CrossOrigin("*")
    public ResponseEntity<Facility> getFacility(@RequestParam String persistentId) {
        return ResponseEntity.ok(facilityService.findByPermanentId(persistentId));
    }

    @PostMapping("/save")
    public ResponseEntity<OkResponseDto> saveFacility(@RequestBody Facility facility) {
        if (facility.getId() == null) {
            facilityService.create(facility);
        } else {
            facilityService.update(facility);
        }
        return ResponseEntity.ok(new OkResponseDto());
    }

    @PostMapping("/delete")
    public ResponseEntity<OkResponseDto> deleteFacility(@RequestBody Facility facility) {
        facilityService.delete(facility);
        return ResponseEntity.ok(new OkResponseDto());
    }

    @PostMapping("/occupancy")
    public ResponseEntity<CurrentFacilityDto> updateOccupancy(@RequestBody OccupancyUpdateDto update) {
        facilityService.updateOccupancyOfCurrentUsersFacility(update);
        return currentFacility();
    }

    @GetMapping("/my")
    public ResponseEntity<CurrentFacilityDto> my() {
        return currentFacility();
    }

    private ResponseEntity<CurrentFacilityDto> currentFacility() {
        Facility facility = facilityService.findCurrentUsersFacility();
        CurrentFacilityDto response = FacilityMapper.toCurrentDto(facility);
        return ResponseEntity.ok(response);
    }
}
