package cz.filipnovak.wntr.rest;

import cz.filipnovak.wntr.dto.ChangePasswordDto;
import cz.filipnovak.wntr.dto.UserDto;
import cz.filipnovak.wntr.mapper.UserMapper;
import cz.filipnovak.wntr.service.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.stream.Collectors;

@RestController
@RequestMapping("/api/user")
public class UserRestController {

    @Autowired
    UserService userService;

    @GetMapping("/list")
    public ResponseEntity<List<UserDto>> getUsers() {
        List<UserDto> users = userService
                .findAll()
                .stream()
                .map(UserMapper::toDto)
                .collect(Collectors.toList());

        return ResponseEntity.ok(users);
    }

    @PostMapping("/create")
    public ResponseEntity<Boolean> createUser(@RequestBody UserDto user) {
        userService.createUser(user);
        return ResponseEntity.ok(Boolean.TRUE);
    }

    @PostMapping("/update")
    public ResponseEntity<Boolean> updateUser(@RequestBody UserDto user) {
        userService.updateUser(user);
        return ResponseEntity.ok(Boolean.TRUE);
    }

    @PostMapping("/change-password")
    public ResponseEntity<Boolean> changePassword(@RequestBody ChangePasswordDto changePassword) {
        userService.changePassword(changePassword);
        return ResponseEntity.ok(Boolean.TRUE);
    }

    @PostMapping("/delete")
    public ResponseEntity<Boolean> deleteUser(@RequestBody UserDto user) {
        userService.delete(user);
        return ResponseEntity.ok(Boolean.TRUE);
    }
}
