package cz.filipnovak.wntr.service;

import cz.filipnovak.wntr.domain.OutreachRecord;
import cz.filipnovak.wntr.domain.User;
import cz.filipnovak.wntr.enumeration.ValidationEnum;
import cz.filipnovak.wntr.repository.OutreachRecordRepository;
import cz.filipnovak.wntr.utility.ValidationUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.Duration;
import java.time.LocalDateTime;
import java.util.List;

@Service
public class OutreachService {

    @Autowired
    UserService userService;

    @Autowired
    SecurityService securityService;

    @Autowired
    private OutreachRecordRepository outreachRecordRepo;

    public List<OutreachRecord> listLatestRecords(Duration duration) {
        ValidationUtil.checkNotNull(duration, ValidationEnum.ILLEGAL_ARGUMENT);

        securityService.userListsAllOutreachRecords();

        LocalDateTime beforeDuration = LocalDateTime.now().minus(duration);
        return outreachRecordRepo.findByCreatedGreaterThanOrderByCreatedDesc(beforeDuration);
    }

    public List<OutreachRecord> listLatestRecordsOfCurrentUser(Duration duration) {
        ValidationUtil.checkNotNull(duration, ValidationEnum.ILLEGAL_ARGUMENT);

        securityService.userListsOwnOutreachRecords();

        User currentUser = userService.findCurrentUser();
        LocalDateTime beforeDuration = LocalDateTime.now().minus(duration);
        return outreachRecordRepo.findByUserAndCreatedGreaterThanOrderByCreatedDesc(currentUser, beforeDuration);
    }

    public void createRecord(OutreachRecord record) {
        ValidationUtil.checkNotNull(record, ValidationEnum.ILLEGAL_ARGUMENT);
        ValidationUtil.checkNull(record.getId(), ValidationEnum.ILLEGAL_ARGUMENT);

        securityService.userCreatesOutreachRecord();

        record.setCreated(LocalDateTime.now());
        record.setUser(userService.findCurrentUser());
        outreachRecordRepo.save(record);
    }
}
