package cz.filipnovak.wntr.service;

import com.password4j.Hash;
import com.password4j.Password;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

@Service
public class PasswordService {

    /**
     * Password pepper added to all passwords prior to hashing.
     */
    @Value("${cz.filipnovak.wntr.password-pepper}")
    private String pepper;

    /**
     * Returns true if given plaintext password matches given hash.
     *
     * @param password plaintext password submitted by user
     * @param hash stored in database
     */
    public boolean matches(String password, String hash) {
        return Password
                .check(password, hash)
                .addPepper(pepper)
                .withBCrypt();
    }

    /**
     * Returns hashed version of given plaintext password.
     *
     * @param password
     * @return hashed password
     */
    public String hash(String password) {
        Hash hash = Password
                .hash(password)
                .addPepper(pepper)
                .withBCrypt();

        return hash.getResult();
    }
}
