package cz.filipnovak.wntr.utility;

import java.text.Normalizer;
import java.util.Locale;
import java.util.StringJoiner;
import java.util.function.Function;

public class StringUtil {

    public static boolean isEmpty(String str) {
        return str == null || str.isEmpty();
    }

    public static String toString(Class<?> clazz, String... props) {
        StringJoiner sj = new StringJoiner(", ", clazz.getSimpleName() + "[", "]");

        for (String prop : props) {
            sj.add(prop);
        }

        return sj.toString();
    }

    /**
     * Generates unique persistendId from given name, with uniqueness checking function as a second param.
     *
     * @param name not empty
     * @param checkIfAlreadyExists not null
     *
     * @return not null
     */
    public static String toPersistentId(String name, Function<String, Boolean> checkIfAlreadyExists) {
        String persistentId = null;

        for (
                int i = 0;
                persistentId == null || checkIfAlreadyExists.apply(persistentId);
                i++
        ) {
            persistentId = StringUtil.toPersistentId(name, i);
        }

        return persistentId;
    }

    /**
     * Turns name to lower case, without diacritic marks, non-characters translitered to underscores, with possible
     * numbered postfix. If order is 0, no postfix should be appended.
     */
    private static String toPersistentId(String name, int order) {
        name = name.toLowerCase(Locale.ROOT);
        name = stripAccents(name);
        name = name.replaceAll("[\\W_]+", "-");
        name = name.replaceAll("-$", "");

        if (order > 0) {
            name += "-" + (order + 1);
        }

        return name;
    }

    /**
     * Removes diacritical marks from given string.
     */
    private static String stripAccents(String s)
    {
        s = Normalizer.normalize(s, Normalizer.Form.NFD);
        s = s.replaceAll("[\\p{InCombiningDiacriticalMarks}]", "");
        return s;
    }
}
