package cz.filipnovak.wntr.utility;

import cz.filipnovak.wntr.enumeration.ValidationEnum;
import cz.filipnovak.wntr.exception.ValidationException;

import java.util.Objects;
import java.util.Optional;

public class ValidationUtil {
    public static void checkNotNull(Object o, ValidationEnum type) {
        if (o == null) {
            fail(type);
        }
    }

    public static void checkNotEmpty(String s, ValidationEnum type) {
        checkNotNull(s, type);

        if (s.length() == 0) {
            fail(type);
        }
    }

    public static void checkNull(Object o, ValidationEnum type) {
        if (o != null) {
            fail(type);
        }
    }

    public static void checkEquals(Object o1, Object o2, ValidationEnum type) {
        if (!Objects.equals(o1, o2)) {
            fail(type);
        }
    }

    public static <T> T getOrFail(Optional<T> optional, ValidationEnum type) {
        return optional.orElseThrow(
                () -> new ValidationException(type)
        );
    }

    public static Object fail(ValidationEnum type) {
        throw new ValidationException(type);
    }
}
