package cz.filipnovak.wntr.service;

import cz.filipnovak.wntr.domain.Counter;
import cz.filipnovak.wntr.domain.Facility;
import cz.filipnovak.wntr.domain.User;
import cz.filipnovak.wntr.enumeration.RoleEnum;
import cz.filipnovak.wntr.repository.FacilityRepository;
import cz.filipnovak.wntr.repository.UserRepository;
import cz.filipnovak.wntr.responsedto.LastUpdateDto;
import cz.filipnovak.wntr.utility.SecurityUtil;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.annotation.Rollback;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.NoSuchElementException;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

@SpringBootTest
@ActiveProfiles("test")
@Transactional
@Rollback
@EnableAutoConfiguration
public class NotificationServiceTest {

    private static final String ADMIN = "admin";

    @Autowired
    private NotificationService notificationService;

    @Autowired
    private FacilityService facilityService;

    @Autowired
    private UserRepository userRepository;

    @Autowired
    private FacilityRepository facilityRepository;

    @BeforeEach
    private void setup() {
        User admin = new User();
        admin.setUsername(ADMIN);
        admin.setRoles(new HashSet<>(Arrays.asList(
                RoleEnum.FACILITY_ADMIN
        )));
        userRepository.save(admin);

        SecurityUtil.setUsername(ADMIN);

        Counter counter = new Counter();
        counter.setTitle("muži");

        List<Counter> counters = new java.util.ArrayList<>();
        counters.add(counter);

        Facility facility = new Facility();
        facility.setName("testing facility");
        facility.setCounters(counters);
        facilityService.create(facility);
    }

    @Test
    public void listExpiredUpdates() {
        LocalDate date = LocalDate.of(2022, 01, 02);

        List<LastUpdateDto> expired = notificationService.listExpiredUpdates(date.atTime(20, 0));
        assertTrue(expired.isEmpty());

        Facility facility = facilityRepository.findByPersistentId("testing-facility").orElseThrow(NoSuchElementException::new);
        facility.setWinter(true);
        facility.setExpirationDecisiveTime(LocalTime.of(19, 00));
        facility.setExpirationNotificationTime(LocalTime.of(20, 00));

        Counter counter = facility.getCounters().get(0);


        counter.setLastUpdate(date.atTime(18, 59));

        expired = notificationService.listExpiredUpdates(date.atTime(18, 0));
        assertTrue(expired.isEmpty());

        expired = notificationService.listExpiredUpdates(date.atTime(19, 0));
        assertTrue(expired.isEmpty());

        expired = notificationService.listExpiredUpdates(date.atTime(20, 0));
        assertFalse(expired.isEmpty());


        counter.setLastUpdate(date.atTime(19, 0));

        expired = notificationService.listExpiredUpdates(date.atTime(18, 0));
        assertTrue(expired.isEmpty());

        expired = notificationService.listExpiredUpdates(date.atTime(19, 0));
        assertTrue(expired.isEmpty());

        expired = notificationService.listExpiredUpdates(date.atTime(20, 0));
        assertTrue(expired.isEmpty());


        counter.setLastUpdate(date.atTime(18, 59));

        expired = notificationService.listExpiredUpdates(date.atTime(18, 0));
        assertTrue(expired.isEmpty());

        expired = notificationService.listExpiredUpdates(date.atTime(19, 0));
        assertTrue(expired.isEmpty());

        expired = notificationService.listExpiredUpdates(date.atTime(20, 1));
        assertFalse(expired.isEmpty());

        counter.setLastUpdate(date.atTime(20, 2));

        expired = notificationService.listExpiredUpdates(date.atTime(20, 2));
        assertTrue(expired.isEmpty());


        facility.setExpirationDecisiveTime(LocalTime.of(23, 00));
        facility.setExpirationNotificationTime(LocalTime.of(1, 00));

        counter.setLastUpdate(date.atTime(22, 59));

        expired = notificationService.listExpiredUpdates(date.atTime(22, 0));
        assertTrue(expired.isEmpty());

        expired = notificationService.listExpiredUpdates(date.atTime(23, 0));
        assertTrue(expired.isEmpty());

        expired = notificationService.listExpiredUpdates(date.plusDays(1).atTime(0, 0));
        assertTrue(expired.isEmpty());

        expired = notificationService.listExpiredUpdates(date.plusDays(1).atTime(1, 0));
        assertFalse(expired.isEmpty());
    }
}