package cz.filipnovak.wntr.service;

import cz.filipnovak.wntr.utility.StringUtil;
import org.apache.commons.lang3.reflect.FieldUtils;
import org.junit.jupiter.api.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.annotation.Rollback;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.transaction.annotation.Transactional;

import static org.junit.jupiter.api.Assertions.*;

@RunWith(SpringRunner.class)
@SpringBootTest
@ActiveProfiles("test")
@Transactional
@Rollback
@EnableAutoConfiguration
class PasswordServiceTest {

    @Autowired
    private PasswordService passwordService;

    @Test
    void matches() throws IllegalAccessException {
        String password = "heslo123koblihaTyPingu_=";
        String hash = passwordService.hash(password);

        assertFalse(passwordService.matches("blalbala", hash));
        assertTrue(passwordService.matches(password, hash));

        Object originalPepper = FieldUtils.readField(passwordService, "pepper", true);
        FieldUtils.writeField(passwordService, "pepper", "spatnyPepa", true);
        assertFalse(passwordService.matches(password, hash));

        FieldUtils.writeField(passwordService, "pepper", originalPepper, true);
        assertTrue(passwordService.matches(password, hash));
    }

    @Test
    void hash() {
        String password = "blabol12Koc-=+kolchoz";
        String hash = passwordService.hash(password);

        assertFalse(StringUtil.isEmpty(hash));
        assertNotEquals(password, hash);
        assertTrue(passwordService.matches(password, hash));

        String utfPassword = "ěščřžýáíéĚŠČŘŽÝÁÍÉüÜůŮúÚ";
        String utfHash = passwordService.hash(utfPassword);

        assertFalse(StringUtil.isEmpty(utfHash));
        assertNotEquals(utfPassword, utfHash);
        assertTrue(passwordService.matches(utfPassword, utfHash));
    }
}