package cz.filipnovak.wntr.service;

import cz.filipnovak.wntr.domain.User;
import cz.filipnovak.wntr.dto.UserDto;
import cz.filipnovak.wntr.enumeration.RoleEnum;
import cz.filipnovak.wntr.repository.UserRepository;
import cz.filipnovak.wntr.utility.SecurityUtil;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.annotation.Rollback;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.transaction.annotation.Transactional;

import java.util.Collections;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertNull;
import static org.junit.jupiter.api.Assertions.assertTrue;
import static org.junit.jupiter.api.Assertions.fail;

@RunWith(SpringRunner.class)
@SpringBootTest
@ActiveProfiles("test")
@Transactional
@Rollback
@EnableAutoConfiguration
class UserServiceTest {

    private static final String ADMIN = "admin";

    @Autowired
    private UserService userService;

    @Autowired
    private UserRepository userRepository;

    @BeforeEach
    public void createTestUsers() {
        User admin = new User();
        admin.setUsername(ADMIN);
        admin.setRoles(Collections.singleton(RoleEnum.USER_ADMIN));
        userRepository.save(admin);
    }

    @Test
    void findUserByName() {
        SecurityUtil.setUsername(ADMIN);

        User nonexistentUser = userService.findUserByName("nonexistent_user");
        assertNull(nonexistentUser);

        UserDto createUser = new UserDto();
        createUser.setUsername("existing_user");
        createUser.setPassword("password");
        userService.createUser(createUser);

        User existingUser = userService.findUserByName("existing_user");
        assertNotNull(existingUser);
    }

    @Test
    void createUser() {
        SecurityUtil.setUsername(ADMIN);

        UserDto createUser = new UserDto();
        createUser.setUsername("some_user");
        createUser.setPassword("password");
        createUser.setRoles(Collections.emptySet());
        userService.createUser(createUser);

        SecurityUtil.setUsername("some_user");

        createUser = new UserDto();
        createUser.setUsername("another_user");
        createUser.setPassword("password");

        try {
            userService.createUser(createUser);
            fail("Non admin is not allowed to create users.");
        } catch (Exception e) {
            assertTrue(e instanceof SecurityException);
        }
    }
}