import React, { createContext } from 'react'

import { isMobile } from "react-device-detect"

const StyleContext = createContext()

export function StyleContextProvider(props) {

    // COLOR

    const defaultColor = '#ffffff'
    const inverseColor = '#232121'
    const activeColor = '#ff9865'
    const errorColor = '#ff5400'
    const warningColor = '#ff5400'
    const headerBackground = '#ffffff'
    const mainBackground = '#272727'

    // FONT

    const fontFamily = "'Roboto', sans-serif"
    const fontWeight = 300

    let fontSize = '1em'
    let navigationFontSize = '5vmin'

    if (isMobile) {
        fontSize = '4.5vmin'
        navigationFontSize = '9vmin'
    }

    const smallerFontSize = '0.7em'
    const titleFontSize = '1.4em'
    const subtitleFontSize = '1.2em'
    const loaderFontSize = '2em'
    const formInputFontSize = '1.2em'

    // LAYOUT

    const inactiveStyle = {
        opacity: '0.3'
    }

    const layoutStyle = {
        width: '100%',
        height: '100%',
        display: 'flex',
        flexFlow: 'column',
        background: 'linear-gradient(90deg, rgba(35,33,33,1) 0%, rgba(35,33,33,1) 49%, rgba(39,39,39,1) 50%, rgba(39,39,39,1) 100%)',
        fontSize: fontSize
    }

    const contentOuterStyle = {
        flex: 1,
        overflow: 'hidden'
    }

    const contentInnerStyle = {
        width: '100%',
        height: '100%',
        display: 'flex',
        background: mainBackground,
        marginTop: '1px'
    }

    const mainStyle = {
        flex: '1',
        padding: '0.8em 0.8em 0',
        color: 'white',
        overflow: 'scroll'
    }    
    
    // HEADER

    const headerStyle = {
        background: headerBackground,
        minHeight: '10%',
        minHeight: '100px',
        overflow: 'hidden',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        borderRadius: '0px 0px 2vw 2vw',
        padding: '1vmax 2vmax 1vmax 2vmax'
    }

    const headerButtonStyle = {
        padding: '1.2vmin 1vmin 0',
        fontSize: navigationFontSize,
        textDecoration: 'none',
        touchAction: 'manipulation'
    }

    const logoWithTitleStyle = {
        flexGrow: '1',
        display: 'flex',
        marginLeft: '10vw'
    }

    const titleBoxStyle = {
        marginLeft: '2vw',
        color: 'black'
    }

    const titleSize = 1.5

    const titleStyle = {
        marginBlockEnd: '0',
        fontSize: (3 * titleSize) + "vmin",
        marginTop: '1.5vw'
    }

    const subtitleStyle = {
        marginBlockStart: '0',
        fontSize: (1.5 * titleSize) + "vmin"
    }

    // NAVIGATION

    const navigationWrapperStyle = {
        display: 'flex',
        flexFlow: 'row',
        alignItems: 'center'
    }

    const navigationIconStyle = {
        float: 'left',
        fontSize: navigationFontSize,
        touchAction: 'manipulation',
        position: 'relative'
    }

    const navigationSubscriptStyle = {
        color: 'white',
        position: 'absolute',
        right: '0',
        bottom: '0',
        background: 'red',
        borderRadius: '8px',
        fontSize: '40%',
        padding: '2px'
    }

    const navigationLabelStyle = {
        marginLeft: '.8em',
        marginBottom: '.3em'
    }

    const navigationLinkStyle = {
        textDecoration: 'none',
        color: 'white'
    }

    // FORM

    const inputStyle = {
        width: '100%',
        borderRadius: '1vmin',
        border: 0,
        padding: '0.4em',
        outline: 'none',
        fontFamily: fontFamily,
        fontWeight: fontWeight,
        fontSize: formInputFontSize
    }

    const rowStyle = {
        position: 'relative',
        marginBottom: '0.5em'
    }

    const halfRowStyle = {
        ...rowStyle,
        display: 'inline-block',
        width: '50%'
    }

    const labelStyle = {
        display: 'inline',
        verticalAlign: 'inherit'
    }

    const radioLabelStyle = {
        paddingLeft: '2vmin'
    }

    const errorStyle = {
        color: errorColor,
        fontSize: smallerFontSize
    }

    // ITEM

    const itemStyle = {
        position: 'relative',
        whiteSpace: 'pre-line',
        borderColor: 'black',
        backgroundColor: 'rgb(35, 33, 33)',
        borderRadius: '0.3em',
        padding: '0.3em 0.6em 0.3em',
        marginBottom: '0.8em'
    }

    const itemDeletedStyle = {
        ...inactiveStyle
    }

    const itemFieldStyle = {
    }

    const itemTitleStyle = {
        color: activeColor,
        fontSize: titleFontSize
    }

    const itemSubtitleStyle = {
        fontSize: subtitleFontSize
    }

    const itemRowStyle = {
        justifyContent: 'space-between',
        alignItems: 'baseline',
        position: 'relative',
        overflowWrap: 'break-word',
        display: 'flex',
        padding: '0.3em 0 0.3em 0'
    }

    const itemTitleRowStyle = {
        paddingBottom: 0
    }

    const itemRowIconStyle = {
        paddingRight: '0.6em'
    }

    const itemAddressStyle = {
        ...itemFieldStyle,
        textAlign: 'left'
    }

    const itemLoaderStyle = {
        height: '1em',
        fontSize: loaderFontSize,
        marginBottom: '-0.5em'
    }

    const itemLinkStyle = {
        color: defaultColor,
        fontStyle: 'italic',
        textDecoration: 'none'
    }

    const itemWarningStyle = {
        color: warningColor
    }

    const buttonStyle = {
        display: 'inline-block',
        position: 'relative',
        padding: '0.35em 1.2em',
        border: '0.1em solid #FFFFFF',
        margin: '0 0.3em 0.3em 0',
        borderRadius: '1vmin',
        boxSizing: 'border-box',
        textDecoration: 'none',
        fontWeight: '300',
        color: defaultColor,
        textAlign: 'center',
        transition: 'all 0.2s',
        background: 'none',
        outline: 'none',
        touchAction: 'manipulation'
    }

    const buttonHoverStyle = {
        color: '#000000',
        background: '#FFFFFF'
    }

    const counterStyle = {
        display: 'inline-block',
        border: '0.1em solid #FFFFFF',
        background: '#FFFFFF',
        borderRadius: '0.3em',
        boxSizing: 'border-box',
        textDecoration: 'none',
        fontWeight: '300',
        color: inverseColor,
        textAlign: 'center',
        transition: 'all 0.2s',
        position: 'relative',
        marginBottom: '0.2em'
    }

    const counterProgressBarStyle = {
        position: 'absolute',
        zIndex: '1',
        backgroundColor: activeColor,
        height: '10%',
        bottom: '0',
        borderRadius: '1vmin'
    }

    const counterContentStyle = {
        position: 'relative',
        zIndex: '9',
        padding: '0.35em 1.2em'
    }

    const facilityTypeTitleStyle = {
        display: 'inline-block',
        width: '100%',
        textAlign: 'center',
        margin: '0.5em 0'
    }

    const facilityTypeDeletedTitleStyle = {
        ...facilityTypeTitleStyle,
        ...inactiveStyle
    }

    const facilityTypeEditStyle = {
        margin: '0 20%'
    }

    const chatAnsweredStyle = {
        opacity: '75%',
        filter: 'grayscale(1)'
    }

    const chatClosedStyle = {
        opacity: '25%',
        filter: 'grayscale(1)'
    }

    const buttonIconStyle = {
        marginRight: '-0.5em'
    }

    const styles = {
        defaultColor,
        inverseColor,
        activeColor,
        errorColor,
        inactiveStyle,
        layoutStyle,
        contentOuterStyle,
        contentInnerStyle,
        mainStyle,
        headerStyle,
        headerButtonStyle,
        logoWithTitleStyle,
        titleBoxStyle,
        titleSize,
        titleStyle,
        subtitleStyle,
        navigationWrapperStyle,
        navigationIconStyle,
        navigationSubscriptStyle,
        navigationLabelStyle,
        navigationLinkStyle,
        inputStyle,
        rowStyle,
        halfRowStyle,
        labelStyle,
        radioLabelStyle,
        errorStyle,
        itemStyle,
        itemDeletedStyle,
        itemFieldStyle,
        itemTitleStyle,
        itemSubtitleStyle,
        itemRowStyle,
        itemTitleRowStyle,
        itemRowIconStyle,
        itemAddressStyle,
        itemLoaderStyle,
        itemLinkStyle,
        itemWarningStyle,
        buttonStyle,
        buttonHoverStyle,
        counterStyle,
        counterProgressBarStyle,
        counterContentStyle,
        facilityTypeTitleStyle,
        facilityTypeEditStyle,
        facilityTypeDeletedTitleStyle,
        chatAnsweredStyle,
        chatClosedStyle,
        buttonIconStyle
    }

    return <StyleContext.Provider value={styles}>
        {props.children}
    </StyleContext.Provider>
}

export default StyleContext