import React, { useState, useContext } from 'react'
import Loader from './Loader'
import StyleContext from '../application/StyleContext'

export default function Button(props) {
    const { buttonStyle, buttonHoverStyle, inactiveStyle } = useContext(StyleContext)

    const [hover, setHover] = useState(false)

    const visible = 'visible' in props ? props.visible : true
    const enabled = 'enabled' in props ? props.enabled : true

    if (!visible) {
        return null
    }

    const onClick = (e) => {
        e.preventDefault()
        e.stopPropagation()
        setHover(false)
        if (enabled) {
            props.action(e)
        }
    }

    let style = { ...buttonStyle, ...props.style }

    if ('scale' in props) {
        style.fontSize = props.scale + 'em'
    }

    if (hover) {
        style = {
            ...style,
            ...buttonHoverStyle,
            ...props.hoverStyle
        }
    }

    if (!enabled) {
        style = {
            ...style,
            ...inactiveStyle
        }
    }

    const labelStyle = {
        visibility: props.loading ? 'hidden' : 'visible'
    }

    return (
        <button
            onMouseEnter={() => setHover(true)}
            onMouseLeave={() => setHover(false)}
            onClick={onClick}
            style={style}
            type={props.type || 'button'}
        >
            <span style={labelStyle}>{props.label}</span>
            <Loader loading={props.loading}/>
        </button>
    )
}
