import React, { useContext, useState } from 'react'
import ApplicationContext from '../application/ApplicationContext'
import StyleContext from '../application/StyleContext'
import Button from './Button'
import { Form, Label, Submit, TextInput, useForm } from './Form'
import { FormRow, Item, Row as ItemRow } from './Item'
import { Column, Row as FlexRow } from '../components/Flex'

export default function Counter(props) {
    const counter = props.counter
    const { counterStyle, counterProgressBarStyle, counterContentStyle, inverseColor, activeColor } = useContext(StyleContext)

    const counterFullStyle = {
        color: counter.occupancy >= counter.capacity && counter.occupancy > 0 && counter.capacity > 0 ? activeColor : inverseColor
    }

    const capacity = counter.capacity ? '/' + counter.capacity : ''

    const progressBarPercentage = counter.capacity ? Math.min(counter.occupancy / counter.capacity * 100, 100) : 0
    const progressBarStyle = {
        ...counterProgressBarStyle,
        width: progressBarPercentage + '%'
    }

    let style = {
        ...counterStyle,
        ...props.style
    }

    if ('scale' in props) {
        style.fontSize = props.scale + 'em'
    }

    return (
        <div style={style} onClick={props.onClick}>
            <div style={progressBarStyle}>

            </div>
            <div style={counterContentStyle}>
                <div>
                    <span style={counterFullStyle}>{counter.occupancy}</span>
                    <span>{capacity}</span>
                </div>
            </div>
        </div>
    )
}

export function CounterEdit({counter, onCancel, onSubmit}) {
    const { form } = useForm({
        id: counter.id,
        occupancy: counter.occupancy
    })

    return <Item>
        <Form form={form} onSubmit={onSubmit}>
            <FormRow>
                <Label></Label>
                <TextInput name="occupancy" form={form}/>
            </FormRow>
            <ItemRow>
                <Button label="Zrušit" action={onCancel}/>
                <Submit label="Uložit" form={form}/>
            </ItemRow>
        </Form>
    </Item>
}

export function CounterPlusMinus({counter}) {
    const { updateOccupancy, setOccupancy } = useContext(ApplicationContext)

    const [counterEdit, setCounterEdit] = useState(false)
    const [minusLoading, setMinusLoading] = useState(false)
    const [plusLoading, setPlusLoading] = useState(false)

    function handleSuccess() {
        setMinusLoading(false)
        setPlusLoading(false)
    }

    function handleError() {
        setMinusLoading(false)
        setPlusLoading(false)
    }

    function handleMinus() {
        setCounterEdit(false)
        if (counter.occupancy > 0) {
            setMinusLoading(true)
            updateOccupancy(counter.id, -1, handleSuccess, handleError)
        }
    }

    function handlePlus() {
        setCounterEdit(false)
        setPlusLoading(true)
        updateOccupancy(counter.id, 1, handleSuccess, handleError)
    }

    function handleCounterSubmit({occupancy}) {
        setCounterEdit(false)
        setPlusLoading(true)
        setMinusLoading(true)
        setOccupancy(counter.id, occupancy, handleSuccess, handleError)
    }

    const handleCounterClicked = () => {
        setCounterEdit(state => !state)
    }

    const counterTitleStyle = {
        marginBlockStart: '1em',
        marginBlockEnd: '1em'
    }

    const buttonStyle = {
        width: '4em',
        margin: 0
    }

    const scale = 1.1

    return <>
        <FlexRow>
            <div style={counterTitleStyle}>{counter.title}</div>
        </FlexRow>
        {
            counterEdit
            ?
                <FlexRow>
                    <CounterEdit counter={counter} onCancel={handleCounterClicked} onSubmit={handleCounterSubmit}/>
                </FlexRow>
            :
                <FlexRow>
                    <Column>
                        <Button label="-" action={handleMinus} loading={minusLoading} style={buttonStyle} scale={scale}/>
                    </Column>
                    <Counter counter={counter} scale={scale} onClick={handleCounterClicked}/>
                    <Column>
                        <Button label="+" action={handlePlus} loading={plusLoading} style={buttonStyle} scale={scale}/>
                    </Column>
                </FlexRow>
        }
    </>
}