import React, { useContext, useEffect, useState } from 'react'
import AiOutlineSearch from '@meronex/icons/ai/AiOutlineSearch';
import { Item } from './Item';
import { TextInput, useForm } from './Form';

export function Filter({filter}) {
    const { form } = useForm()

    useEffect(() => filter.setQuery(form.getValue('query')))

    return <Item>
        <AiOutlineSearch/>
        <TextInput name="query" form={form}/>
    </Item>
}

export function Highlight({filter, children}) {
    const query = filter
        && filter.getQuery()
        || ""
    
    const parts = children
        && children.split(new RegExp(`(${query})`, 'gi'))
        || []
    
    let k = 0
    return <>
        {
            parts.map(part =>
                part.toLowerCase() === query.toLowerCase()
                    ? <mark key={k++}>{part}</mark>
                    : part
            )
        }
    </>;
}

export function useFilter() {
    const [query, setQuery] = useState("")

    const anyMatch = (strings) => {
        for (let s of strings) {
            if (s && s.toLowerCase().indexOf(query.toLowerCase()) !== -1) {
                return true
            }
        }
        return false
    }

    return {
        getQuery: () => query,
        setQuery: q => setQuery(q),
        anyMatch: l => anyMatch(l)
    }
}