import React, { useContext } from 'react'

import { NavLink } from 'react-router-dom'
import ApplicationContext from '../application/ApplicationContext'
import StyleContext from '../application/StyleContext'

function Navigation(props) {
    const Icon = props.icon ? props.icon : () => null

    const { showMenu } = useContext(ApplicationContext)
    const { navigationWrapperStyle, navigationIconStyle, navigationSubscriptStyle, navigationLabelStyle, navigationLinkStyle, activeColor, inactiveStyle } = useContext(StyleContext)

    const condition = "condition" in props ? props.condition : true
    
    let subscript = "subscript" in props ? props.subscript : null
    if (subscript != null) {
        subscript = String(subscript)
    }

    const navigationStyle = {
        padding: '1vh',
        fontSize: '3.5vh',
        ...(condition ? {} : inactiveStyle)
    }
    
    const linkActiveStyle = {
        color: activeColor
    }

    const inner = <div style={navigationWrapperStyle}>
        <div style={navigationIconStyle}>
            <Icon />
            {
                condition && subscript && <div style={navigationSubscriptStyle}>{subscript}</div>
            }
        </div>
        {
            showMenu && <span style={navigationLabelStyle}>{props.title}</span>
        }
    </div>
    

    return (
        <div style={navigationStyle}>
            {
                condition && <NavLink to={props.path} style={navigationLinkStyle} activeStyle={linkActiveStyle}>{inner}</NavLink>
            }
            {
                !condition && <div style={navigationLinkStyle}>{inner}</div>
            }
        </div>
    )
}

export default Navigation