import React, { useContext } from 'react'

import BiTimer from '@meronex/icons/bi/BiTimer'
import BsFillChatDotsFill from '@meronex/icons/bs/BsFillChatDotsFill'
import BsHouse from '@meronex/icons/bs/BsHouse'
import FaCity from '@meronex/icons/fa/FaCity'
import SiGooglesheets from '@meronex/icons/si/SiGooglesheets'
import RiUserSettingsLine from '@meronex/icons/ri/RiUserSettingsLine'
import RiListSettingsLine from '@meronex/icons/ri/RiListSettingsLine'
import FaWalking from '@meronex/icons/fa/FaWalking'

import { Column } from '../components/Flex'
import Navigation from '../components/Navigation'
import ApplicationContext from '../application/ApplicationContext'

const menuStyle = {
    background: '#232121',
    borderRadius: '0 2vw 2vw 0',
    padding: '2vw'
}

function Menu() {
    const { currentUser, myFacility, countNotifications, countUnreadChats } = useContext(ApplicationContext)
    return (
        <Column style={menuStyle}>
            <Navigation path="/facilities/my" title="Naše zařízení" icon={BsHouse} condition={myFacility.hasFacility}/>
            <Navigation path="/facilities/list" title="Seznam zařízení" icon={FaCity} />
            <Navigation path="/reports" title="Reporty" icon={SiGooglesheets} condition={currentUser.permissions.VIEW_REPORTS}/>
            <Navigation path="/notifications" title="Oznámení" icon={BiTimer} condition={currentUser.permissions.VIEW_NOTIFICATIONS} subscript={countNotifications()}/>
            <Navigation path="/chat" title="Chat" icon={BsFillChatDotsFill} condition={currentUser.permissions.REPLY_TO_ANY_CHAT} subscript={countUnreadChats()}/>
            <Navigation path="/outreach/records" title="Terénní šetření" icon={FaWalking} condition={currentUser.permissions.VIEW_ALL_OUTREACH_RECORDS || currentUser.permissions.VIEW_OWN_OUTREACH_RECORDS} />
            <Navigation path="/admin/facilities" title="Administrace zařízení" icon={RiListSettingsLine} condition={currentUser.permissions.UPDATE_OWN_FACILITY || currentUser.permissions.UPDATE_ANY_FACILITY} />
            <Navigation path="/admin/users" title="Administrace uživatelů" icon={RiUserSettingsLine} condition={currentUser.permissions.CHANGE_OWN_PASSWORD || currentUser.permissions.LIST_USERS}/>
        </Column>
    )
}

export default Menu