import React, { useContext, useEffect } from 'react'
import ApplicationContext from '../application/ApplicationContext'
import List from '../components/List'
import Facility from '../components/Facility'
import { Title } from '../components/Item'
import StyleContext from '../application/StyleContext'
import { Filter, Highlight, useFilter } from '../components/Filter'

function InnerList(props) {
    const { facilityTypeTitleStyle } = useContext(StyleContext)
    
    return <>
        {
            props.type.name &&
            <Title style={facilityTypeTitleStyle}><Highlight filter={props.filter}>{props.type.name}</Highlight></Title>
        }
        <List items={props.byTypes[props.type.id]} item="facility" order="-winter name">
            <Facility filter={props.filter} />
        </List>
    </>
}

function FacilitiesList(props) {
    const { facilities, fetchFacilities } = useContext(ApplicationContext)

    useEffect(() => fetchFacilities(), [])

    const filter = useFilter()

    const defaultFacilityType = { id: 0, name: 'Ostatní', position: 1000 }

    const types = {}
    const byTypes = {}

    facilities
        .filter(f => !f.deleted)
        .filter(f => filter.anyMatch([
            f.name,
            f.organization,
            f.address,
            f.facilityDistrict && f.facilityDistrict.name,
            f.facilityType && f.facilityType.name || defaultFacilityType.name]))
        .forEach(f => {
            const type = f.facilityType || defaultFacilityType

            types[type.id] = type

            byTypes[type.id] = byTypes[type.id] || []
            byTypes[type.id].push(f);
        })
    
    return <>
        <Filter filter={filter}/>
        <List items={Object.values(types)} item="type" order="position">
            <InnerList byTypes={byTypes} filter={filter}/>
        </List>
    </>
}

export default FacilitiesList