import React, { useContext, useEffect } from 'react'

import List from '../components/List'

import ApplicationContext from '../application/ApplicationContext'
import FacilityType from '../components/FacilityType'
import { Title } from '../components/Item'
import Facility from '../components/Facility'
import { Filter, useFilter } from '../components/Filter'

function FacilityAdmin(props) {
    const {
        currentUser, myFacility,
        facilities, fetchFacilities,
        facilityTypes, fetchFacilityTypes, fetchFacilityDistricts
    } = useContext(ApplicationContext)

    useEffect(() => fetchFacilityDistricts(), [])
    useEffect(() => fetchFacilityTypes(), [])
    useEffect(() => fetchFacilities(), [])

    const filter = useFilter()

    const filteredFacilityTypes = facilityTypes
        .filter(ft => !ft.deleted)
        .filter(ft => filter.anyMatch([ft.name]))
        .filter(_ => currentUser.permissions.UPDATE_FACILITY_TYPE)

    const filteredFacilities = facilities
        .filter(f => !f.deleted)
        .filter(f => filter.anyMatch([
            f.name,
            f.organization,
            f.address,
            f.facilityDistrict && f.facilityDistrict.name,
            f.facilityType && f.facilityType.name || 'Ostatní'
        ]))
        .filter(f => currentUser.permissions.UPDATE_ANY_FACILITY || f.id === myFacility.id)

    return <>
        {
            currentUser.permissions.UPDATE_ANY_FACILITY &&
            <Filter filter={filter}/>
        }
        {
            currentUser.permissions.CREATE_FACILITY_TYPE &&
            <FacilityType />
        }
        <List items={filteredFacilityTypes} item="type" order="deleted position" keyFunction={e => e.id}>
            <FacilityType filter={filter} />
        </List>

        <Facility editable={true} style={{background: 'none'}} />
        <List items={filteredFacilities} item="facility" order="deleted -winter name">
            <Facility editable={true} filter={filter} />
        </List>
    </>
}

export default FacilityAdmin