import React, { useContext, useState } from 'react'
import { Form, useForm, Label, TextInput, PasswordInput, Submit } from '../components/Form'
import ApplicationContext from '../application/ApplicationContext'
import StyleContext from '../application/StyleContext'
import { Row, ErrorRow, Item, Title } from '../components/Item'
import Button from '../components/Button'

export default function Login(props) {
    const [loading, setLoading] = useState(false)
    const [error, setError] = useState(null)

    const { form } = useForm()

    const { currentUser, loginUser, logoutUser } = useContext(ApplicationContext)

    const handleSuccess = () => {
        setLoading(false)
        setError(null)
    }

    const handleError = (e) => {
        setLoading(false)
        setError(e)
    }

    const handleSubmit = (formData) => {
        setLoading(true)
        loginUser(formData, handleSuccess, handleError)
    }

    const handleLogout = () => {
        setLoading(true)
        logoutUser(handleSuccess, handleError)
    }

    const errorMessages = {
        'WRONG_CREDENTIALS': 'Chybné přihlašovací údaje.',
        '502': 'Server nestihl odpovědět ve stanoveném čase.',
        'REQUEST_ERROR': 'Chyba komunikace se serverem.'
    }

    if (!currentUser.authenticated) {
        return <Item>
            <Form form={form} onSubmit={handleSubmit}>
                <Row>
                    <Title>Přihlášení</Title>
                </Row>
                <Row>
                    <Label>Uživatelské jméno</Label>
                </Row>
                <Row>
                    <TextInput form={form} name="username"/>
                </Row>

                <Row>
                    <Label>Heslo</Label>
                </Row>
                <Row>
                    <PasswordInput form={form} name="password"/>
                </Row>

                <ErrorRow messages={errorMessages} error={error} />

                <Row>
                    <Submit form={form} label="Odeslat" loading={loading} />
                </Row>
            </Form>
        </Item>
    } else {
        return <Item>
            <Row>
                <Title>Přihlášený uživatel</Title>
            </Row>
            <Row>{currentUser.username}</Row>

            <ErrorRow messages={errorMessages} error={error} />

            <Row>
                <Button label="Odhlásit" loading={loading} action={handleLogout} />
            </Row>
        </Item>
    }
}