import React, { useContext, useEffect } from 'react'

import { CounterPlusMinus } from '../components/Counter'
import { Column, Row } from '../components/Flex'
import ApplicationContext from '../application/ApplicationContext';
import { ErrorRow, Title, Subtitle } from '../components/Item';
import StyleContext from '../application/StyleContext';

function MyFacility() {
    const { currentUser, myFacility, fetchMyFacility } = useContext(ApplicationContext)
    const { inactiveStyle } = useContext(StyleContext)
    
    useEffect(() => {
        if (currentUser.authenticated) {
            fetchMyFacility()
        }
    }, [])

    const errorMessages = {
        '404': 'Nemohu načíst zařízení.'
    }

    const style = myFacility.hasFacility ? {} : {
        ...inactiveStyle
    }

    return <>
        {
            myFacility.error && <ErrorRow messages={errorMessages} error={myFacility.error}/>
        }
        <Column style={style}>
            <Row>
                <div>
                    <Row><Title>{myFacility.name}</Title></Row>
                    <Row><Subtitle>{myFacility.organization}</Subtitle></Row>
                </div>
            </Row>
            {
                myFacility.counters &&
                myFacility.counters
                    .filter(c => !c.disabled && c.title)
                    .map((counter, i) => <CounterPlusMinus counter={counter} key={i} />)
            }
            <Row></Row>
        </Column>
    </>
}

export default MyFacility