import React, { useContext, useEffect, useState } from 'react'
import ApplicationContext from '../application/ApplicationContext'
import List from '../components/List'
import { Field, Item, Subtitle, Title } from '../components/Item'
import SuBellSnooze from '@meronex/icons/su/SuBellSnooze';
import useInterval from '../utils/use-interval';

function CounterUpdateNotification(props) {
    const { facilityName, counterName, counterId, lastUpdate } = props.update
    const d = new Date(lastUpdate)
    const yesterday = new Date(new Date().getTime() - 24 * 60 * 60 * 1000)

    const { snoozeCounterUpdate } = useContext(ApplicationContext)
    const [loading, setLoading] = useState(false)

    const handleSuccess = () => {
        setLoading(false)
    }

    const handleError = (e) => {
        setLoading(false)
        console.log("Error: " + e)
    }

    const snoozeButtonClicked = () => {
        setLoading(true)
        snoozeCounterUpdate(counterId, handleSuccess, handleError)
    }

    const titleStyle = d > yesterday
        ? { color: 'white' }
        : {}

    const snoozeButtonLabel = <>
        Odložit
        <SuBellSnooze style={{margin: '0 -0.4em 0 0.4em'}}/>
    </>

    return <>
        <Item>
            <div style={{display: 'flex', flexWrap: 'wrap'}}>
                <div style={{flex: '1'}}>
                    <Field><Title style={titleStyle}>{facilityName}</Title></Field>
                    <Field><Subtitle>{counterName}</Subtitle></Field>
                    <Field>{d.toLocaleString()}</Field>
                </div>
            </div>
        </Item>
    </>
}

export default function Notifications(props) {
    const { counterUpdates, fetchCounterUpdates } = useContext(ApplicationContext)
    
    useInterval(() => fetchCounterUpdates())

    return <>
        <List items={counterUpdates} item="update">
            <CounterUpdateNotification/>
        </List>
    </>
}