import { useState } from 'react';

export function Highlight({filter, children}) {
    const query = filter.getQuery()
    if (!query) {
        return <>{children}</>
    }
    
    const parts = children
        && children.split(new RegExp(`(${query})`, 'gi'))
        || []
    
    let k = 0
    return <>
        {
            parts.map(part =>
                part.toLowerCase() === query.toLowerCase()
                    ? <mark key={k++}>{part}</mark>
                    : part
            )
        }
    </>;
}

export function useFilter() {
    const [query, setQuery] = useState("")

    const anyMatch = (strings) => {
        for (let s of strings) {
            if (s && s.toLowerCase().indexOf(query.toLowerCase()) !== -1) {
                return true
            }
        }
        return false
    }

    return {
        getQuery: () => query,
        setQuery: q => setQuery(q),
        anyMatch: l => anyMatch(l)
    }
}