import Head from 'next/head'
import { LogoCssp, LogoEuOpz, LogoPraha } from './logo'
import styled from 'styled-components'
import Menu from './menu'
import Chat from './chat'
import { useRouter } from 'next/router'
import { themeColor } from '../utils/theme'
import home from '../templates/home'
import generic from '../templates/page'
import document from '../templates/document'
import { getPrimaryColorByPath } from '../lib/menu.mjs'

const Container = styled.div`
    display: flex;
    flex-direction: column;
    min-height: 100vh;

    background-color: ${({ theme }) => theme.colors.white};

    & A {
        color: inherit;
        text-decoration: none;
        transition: 400ms ease;

        background-image:
            linear-gradient(${({ theme }) => theme.colors.white}, ${({ theme }) => theme.colors.white}),
            linear-gradient(${themeColor}, ${themeColor});
        background-size: 100% 2px, 0 2px;
        background-position: 100% 100%, 0 100%;
        background-repeat: no-repeat;

        &:hover {
            background-size: 0 2px, 100% 2px;
        }
    }

    & .home A {
        background-image:
            linear-gradient(${({ theme }) => theme.colors.white}, ${({ theme }) => theme.colors.white}),
            linear-gradient(${({ theme }) => theme.colors.grey}, ${({ theme }) => theme.colors.grey});
    }

    & img {
        height: auto;
    }
`

const Header = styled.header`
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    align-items: center;
    padding: 1vmax;

    box-shadow: ${({ theme }) => theme.boxShadows.section};
`

const Logo = ({ href, children }) =>
    <LogoDiv>
        <a href={href}>{children}</a>
    </LogoDiv>

const LogoDiv = styled.div`
    height: 3rem;
    display: flex;

    &:nth-child(1) {
        padding: 0 2em;
        flex-grow: 1;
    }

    & IMG {
        max-height: 100%;
        max-width: 100%;
        align-self: center;
        padding: 2px;
    }

    &.left {
        flex-grow: 
    }

    & A {
        background-image: none;
    }
`

const Strip = styled.div`
    display: flex;
    flex-wrap: nowrap;
    justify-content: space-between;
    padding: 1rem 1.5rem;

    color: ${({ theme }) => theme.colors.white };
    background: ${({ theme }) => theme.colors.grey };
    box-shadow: ${({ theme }) => theme.boxShadows.section};

    position: relative;
`

const Footer = styled.footer`
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    align-items: center;
    padding: 1rem;
    margin-top: auto;
    margin-bottom: 0;
    bottom: 0;

    box-shadow: ${({ theme }) => theme.boxShadows.section};
`

export default function Layout({ page, template, children }) {
    const router = useRouter()
    const color = getPrimaryColorByPath(router.asPath)

    const templates = {
        home,
        page: generic,
        document
    }
    const Template = templates[template || 'page']

    return <Container color={color}>
        <Head>
            <title>{page.title}</title>
            <link rel="icon" href="/favicon.ico" />
            <meta name="description" content="Portál Centra sociálních služeb Praha pro osoby bez domova" />
            <base target="_blank" />
        </Head>

        <Header>
            <Logo href="https://european-union.europa.eu">
                <LogoEuOpz/>
            </Logo>
            <Logo href="https://www.praha.eu">
                <LogoPraha/>
            </Logo>
            <Logo href="https://www.csspraha.cz">
                <LogoCssp />
            </Logo>
        </Header>

        <Strip>
            <Menu />
            <Chat />
        </Strip>

        <Template h1={page.title} color={color}>{children}</Template>
        
        <Footer>
            <div></div>
            <div>&copy;2021 Centrum sociálních služeb Praha</div>
        </Footer>
    </Container>
}