import Link from 'next/link'
import { useRouter } from 'next/router'
import { getSubpages, getSiblings, getParent, getByPath, sanitize } from '../lib/menu.mjs'
import { useAppContext } from '../service/ctx'

function Page({ page, currentPath }) {
    return <>
        <span> &gt; </span>
        {
            (page.path && page.path != currentPath)
                && <Link href={page.path}>{page.title}</Link>
                || page.title
        }
    </>
}

export default function Menu({}) {
    const currentPath = sanitize(useRouter().asPath)

    const pages = []
    for (
        let p = currentPath;
        p.length > 0;
        p = p.substring(0, p.lastIndexOf("/"))
    ) {
        if (p.length > 1) {
            const page = getByPath(p)
            if (page) {
                pages.push(page)
            }
        }
    }
    pages.reverse()

    return <>
        <nav className={currentPath == '/' ? 'home' : undefined}>
            <Link href="/">Domů</Link>
            {
                pages.map((p, k) => <Page page={p} currentPath={currentPath} key={k}/>)
            }
        </nav>
    </>
}

export function LeftMenu({}) {
    const router = useRouter()
    const path = router.asPath;

    const parent = getParent(path)

    const siblings = getSiblings(path)
    
    const subpages = getSubpages(path)

    return <>
        <nav>
            <div>
                {
                    parent && <Link href={parent.path}>{parent.title}</Link>
                }
            </div>
            {
                siblings.map(p => <div className="subpage" key={p.path}>
                    {
                        p.path == path
                            ? <strong>{p.title}</strong>
                            : <Link href={p.path}>{p.title}</Link>

                    }
                    {
                        p.path == path && subpages.map(p => <div className="subpage" key={p.path}>
                            <Link href={p.path}>{p.title}</Link>
                        </div>)
                    }
                </div>)
            }

        </nav>
    </>
}