import { useEffect, useRef } from "react"
import styled from 'styled-components'
import { device } from '../utils/media'

function debounce(func, timeout = 25) {
    let timer
    return (...args) => {
        clearTimeout(timer)
        timer = setTimeout(() => {
            func.apply(this, args)
        }, timeout)
    }
}

export default function Sticky({ children }) {
    const absolute = useRef()

    useEffect(() => {
        const setTop = debounce((t) => absolute.current.style.top = t + 'px')

        function handleScroll() {
            const winTop = window.pageYOffset
            const winBottom = winTop + window.innerHeight
            
            const relTop = absolute.current.parentElement.offsetTop
            const absTop = relTop + absolute.current.offsetTop
            const absHeight = absolute.current.offsetHeight
            const absBottom = absTop + absHeight

            const menuSmallerThanWindow = window.innerHeight > absHeight
            const maxTop = absolute.current.parentElement.parentElement.offsetHeight - absHeight - 18

            let newTop = null
            if (menuSmallerThanWindow || absTop - winTop > 0) {
                newTop = winTop - relTop
            } else if (winBottom - absBottom > 0) {
                newTop = winBottom - absHeight - relTop
            }

            if (newTop) {
                if (newTop < 0) {
                    newTop = 0
                } else if (newTop > maxTop) {
                    newTop = maxTop
                }

                setTop(newTop)
            }
        }

        window.addEventListener('scroll', handleScroll, false)
        window.addEventListener('resize', handleScroll, false)
        return () => {
            window.removeEventListener('scroll', handleScroll)
            window.removeEventListener('resize', handleScroll)
        }
    }, [])

    return <Relative>
        <Absolute ref={absolute}>{children}</Absolute>
    </Relative>
}

const Relative = styled.div`
    position: relative;
`

const Absolute = styled.div`
    @media ${device.tablet} {
        position: absolute;
        top: 0;
    }
`
