import { useRouter } from "next/router"
import { getPrimaryColorByPath, isHome, getSubpages } from "../lib/menu.mjs"
import Icon from "./icon"
import { Tile } from "./tile"

export function Subpages({ parent }) {
    const subpages = getSubpages(parent)

    return <ul>
        {
            subpages
                .slice(0, 3)
                .map((p, i) => <li key={i}>{p.title}</li>)
        }
    </ul>
}

export function SubpageTile({ page, width, isHome }) {
    const color = getPrimaryColorByPath(page.path)

    return <Tile title={page.title} href={page.path} color={color}>
        {
            isHome
                ? <Subpages parent={page.path}/>
                : <Icon type={page.icon}/>
        }
    </Tile>
}

export default function SubpageTiles({ children }) {
    const parent = useRouter().asPath

    const subpages = getSubpages(parent).filter(p => !p.href)

    if (subpages.length == 0) {
        return null
    }

    return <>
        {
            subpages.map((p, i) => <SubpageTile page={p} key={i} isHome={isHome(parent)} />)
        }
        {children}
    </>
}