import styled from 'styled-components'
import { device } from '../utils/media'
import { themeColor } from '../utils/theme'
import { useState } from 'react'
import { useRouter } from 'next/router'
import Link from './link'
import { isHome } from '../lib/menu.mjs'

export function Tile({ title, children, color, href, className, background }) {
    const [over, setOver] = useState('')

    const width = isHome(useRouter().asPath)
        ? '50%'
        : null

    let inner = <Inner
            color={color}
            className={'tile' + ' ' + over + ' ' + className}
            onMouseEnter={() => href && setOver('over')}
            onMouseLeave={() => setOver('')}
    >
        <Title color={color}>
            <h2>{title}</h2>
        </Title>
        <ContentWrapper background={background}>
            {children}
        </ContentWrapper>
    </Inner>

    return <Outer width={width}>
        <Link href={href}>{inner}</Link>
    </Outer>
}

const Outer = styled.div`
    width: 100%;
    padding: 0 1rem 1rem 0;

    @media ${device.tablet} {
        width: ${({ width }) => width || '33%'};
        padding-right: 1rem;

        &:nth-child(even) {
//            padding-right: 0;
        }
    }
`

const Inner = styled.div`
    display: flex;
    flex-direction: column;

    border-radius: ${({ theme}) => theme.borderRadii.tile};
    box-shadow: ${({ theme }) => theme.boxShadows.tile};
    transition: box-shadow ease 100ms, transform ease 150ms;

    &.over {
        box-shadow: ${({ theme }) => theme.boxShadows.tileHover};
        transform: ${({ theme }) => theme.transforms.tileHover};

        cursor: pointer;
    }

    &.no-border {
        box-shadow: none;
    }
`

const Title = styled.div`
    width: 100%;
    border-radius: ${({ theme}) => theme.borderRadii.tile} ${({ theme}) => theme.borderRadii.tile} 0 0;
    background: ${themeColor};
    padding: 1rem 1rem 0.8rem 1rem;
    
    & H2 {
        color: ${({ theme }) => theme.colors.white};

        display: inline-block;
        transition: 400ms ease;
        background-image:
            linear-gradient(${themeColor}, ${themeColor}),
            linear-gradient(${({ theme }) => theme.colors.white}, ${({ theme }) => theme.colors.white});
        background-size: 100% 2px, 0 2px;
        background-position: 100% 100%, 0 100%;
        background-repeat: no-repeat;
    }

    .over & H2 {
        background-size: 0 2px, 100% 2px;
    }
`

const ContentWrapper = styled.div`
    flex-grow: 1;

    display: flex;
    justify-content: center;
    align-items: center;

    border-radius: 0 0 ${({ theme}) => theme.borderRadii.tile} ${({ theme}) => theme.borderRadii.tile};
    background: ${({ background }) => background || 'none'};
    padding: 1rem;

    & UL {
        width: 100%;
        list-style: none;
        margin-block-start: 0.5rem;
        margin-block-end: 0.5rem;
        margin-inline-start: 0;
        margin-inline-end: 0;
        padding-inline-start: 1rem;
    }

    & LI + LI {
        margin-top: 0.5rem;
    }
`
