export function sanitize(str) {
    str = str.split('#')[0]
    str = str.split('?')[0]

    if (str.endsWith('/')) {
        str = str.substring(0, str.length - 1)
    }

    if (!str.startsWith('/')) {
        str = '/' + str
    }

    return str
}

function pageDepth(str) {
    return str == '/'
        ? 0
        : sanitize(str).split('/').length - 1
}

function removeLastPart(str) {
    str = sanitize(str)
    return str.substring(0, str.lastIndexOf('/'))
}

let pages = {}

export const setPages = p => pages = p

export const getByPath = (path) => {
    path = sanitize(path)
    return path && pages[path]
}

export const getSubpages = (path) => {
    path = sanitize(path)
    const childDepth = pageDepth(path) + 1

    return Object.keys(pages)
        .filter(p => p.startsWith(path))
        .filter(p => pageDepth(p) == childDepth)
        .map(p => getByPath(p))
        .filter(p => p)
        .sort((p1, p2) => p1.order - p2.order)
}

export const getParent = (path) => {
    path = sanitize(path)
    const parentPath = removeLastPart(path)
    return getByPath(parentPath) || getParent(parentPath)
}

export const getSiblings = (path) => {
    path = sanitize(path)
    return getSubpages( getParent(path).path )
}

export const getPrimaryColorByPath = (path) => {
    path = sanitize(path)
    return path.startsWith('/potrebuji-pomoc')
        ? 'red'
        : path.startsWith('/chci-pomahat')
            ? 'blue'
            : 'black'
}

export const isHome = (path) => {
    return sanitize(path) == '/'
}
