import styled from 'styled-components'
import Layout from '../components/layout'
import Link from '../components/link'
import SubpageTiles from '../components/subpage-tiles'
import { Tile } from '../components/tile'
import { getByPath, getPages, getNews } from '../lib/cms'
import { setPages } from '../lib/menu.mjs'

export default function Home({ page, pages, news }) {
    setPages(pages)
	
	return (
		<Layout template="home" page={page}>
			<SubpageTiles>
				<Tile title="Aktuality z CSS Praha" className="no-border">
					<FullWidth>
						<News news={news}/>
					</FullWidth>
				</Tile>

				<Tile title="Kontakt">
					<FullWidth>
						<div dangerouslySetInnerHTML={{ __html: page.content }} />
					</FullWidth>
				</Tile>
			</SubpageTiles>
		</Layout>
	)
}

function News({ news }) {
	return news.map(n => {
		return <Smaller>
			<a href={n.path}>
				<h3 dangerouslySetInnerHTML={{ __html: n.title}}/>
				<div dangerouslySetInnerHTML={{ __html: n.excerpt }}/>
			</a>
		</Smaller>
	})
}

const Smaller = styled.div`
	font-size: 0.8rem;
	margin-bottom: 1em;

	& P {
		margin-top: 0.2em;
	}

	&:hover {
		cursor: pointer;
	}

	&:hover H3 {
		text-decoration: underline;
	}
`

const FullWidth = styled.div`
	width: 100%;
`

export async function getStaticProps({ params }) {
    const page = await getByPath('/')
    const pages = await getPages()
	const news = await getNews()

    return {
        props: { page, pages, news }
    }
}