import { lastModified } from "../lib/cms.mjs";
import shell from "shelljs"
import { statSync } from "fs";

function sleep(ms) {
    return new Promise((resolve) => setTimeout(resolve, ms))
}

async function waitAfter(callback, ms = 1000) {
    while (true) {
        callback()
        await sleep(ms)
    }
}

let previous = null

async function check() {
    try {
        const current = await lastModified()
        if (!previous || previous.getTime() != current.getTime()) {
            console.log("changed: " + current)
            shell.exec("npm run build")
        } else {
            console.log("unchanged: " + current)
        }
        
        previous = current    
    } catch (err) {
        console.log(err)
    }
}

let previousPublishTime = null

async function checkPublish() {
    try {
        const stats = statSync("/tmp/wntr-web-publish")
        const currentPublishTime = stats.mtime

        if (previousPublishTime && currentPublishTime > previousPublishTime) {
            console.log("published: " + currentPublishTime)
            shell.exec("cp -r /var/www/wntr-pre/* /var/www/wntr-prod")
        }

        previousPublishTime = currentPublishTime
    } catch (error) {
        console.log("not published: " + error)
    }
}

waitAfter(() => {
    check()
    checkPublish()
}, 5 * 1000)
