import { useState } from "react"
import { post } from "../lib/backend.mjs"

function randomString(length = 5, chars = 'abcdefghijklmnopqrstuvwxyz') {
    if (length < 1 || chars.length < 2) {
        throw "Illegal argument."
    }

    const max = chars.length

    let result = ''
    for (let i = 0; i < length; i++) {
        const pos = Math.floor(Math.random() * max)
        result += chars.charAt(pos)
    }
    return result
}

const CONVERSATION_KEY = 'chat.conversation'

function getConversation() {
    const serialized = window.localStorage.getItem(CONVERSATION_KEY)
    return serialized && JSON.parse(serialized)
}

function setConversation(conversation) {
    const serialized = JSON.stringify(conversation)
    window.localStorage.setItem(CONVERSATION_KEY, serialized)
}

export default function ChatService(ctx) {
    const [messages, setMessages] = useState([])

    const startConversation = async () => {
        try {
            const res = await post('/chat/conversation/start', { secret: randomString() })
            setConversation(res.data)
            return res.data
        } catch (err) {
            console.log("error: " + err)
        }
    }

    const fetchMessages = () => {
        const conversation = getConversation()

        if (!conversation) {
            return
        }

        post('/chat/message/list', { id: conversation.id, secret: conversation.secret })
            .then(r => setMessages(r.data))
            .catch(err => console.log("error: " + err))
    }
    
    const getMessages = () => messages

    const submitMessage = async (message, onSuccess, onError) => {
        const conversation = getConversation() || await startConversation()

        post('/chat/message/question',{
                conversationId: conversation.id,
                conversationSecret: conversation.secret,
                messageText: message
            })
            .catch(err => console.log("error: " + err))

        onSuccess();
    }

    return {
        fetchMessages,
        getMessages,
        submitMessage
    }
}