import { useEffect } from 'react'
import styled from 'styled-components'
import createIndex from '../components/indexed'
import Sticky from '../components/sticky'
import { device } from '../utils/media'
import { themeColor } from '../utils/theme'
import { Heading, Container } from './home'
import { Middle } from './page'

const Left = styled.div`
    padding: 1rem 1rem 2rem 1rem;
    width: 100%;

    @media ${device.tablet} {
        width: 30%;
    }

    & UL {
        padding: 0;
        margin: 0;
        list-style: none;
    }

    & .L1 {
        margin-left: 1em;
    }

    & .L2,
    & .L3,
    & .L4 {
        display: none;
    }
`

const Right = styled(Middle)`
    @media ${device.tablet} {
        width: 70%;
    }

    padding-top: 0;

    & #content *:first-child {
        margin-top: 0;
    }
    
    & H1,
    & H2,
    & H3,
    & H4,
    & H5 {
        margin-top: 1em;
    }

    & table {
        border-collapse: collapse;
        margin-top: 1em;
        font-size: 0.7em;
    }

    & th,
    & td {
        border: 1px solid black;
        padding: 4px 2px;
    }

    & th p,
    & td p {
        margin-top: 0;
    }

    & FIGURE.wp-block-pullquote {
        border: 1px solid ${themeColor};
        box-shadow: ${({ theme }) => theme.boxShadows.section};
        border-radius: ${({ theme}) => theme.borderRadii.tile};
        padding: 1em;
        margin-top: 1em;

        font-style: italic;
    }

    & FIGURE P:first-child {
        font-weight: bold;
    }

    & FIGURE CITE {
        display: block;
        margin-top: 1em;
    }
`

export default function Template({ h1, color, children }) {
    useEffect(() => {
        createIndex('content', 'index')
    }, [])

    return <Container>
        <Heading color={color}>{h1}</Heading>

        <Left>
            <Sticky>
                <nav id="index">
                </nav>
            </Sticky>
        </Left>

        <Right color={color}>
            <div id="content">{children}</div>
        </Right>
    </Container>
}