import styled from 'styled-components'
import { device } from '../utils/media'
import { themeColor, themeSecondaryColor } from '../utils/theme'
import { Heading, Main, Container } from './home'
import SubpageTiles from '../components/subpage-tiles'
import Wrapper from '../components/wrapper'
import DefinedTiles from '../components/defined-tiles'
import { useEffect } from 'react'

const PaddingSides = styled.div`
    padding: 0 0 0 1rem;
    width: 100%;
`

export const Middle = styled.main`
    width: 100%;
    padding: 1rem;

    & P A,
    & UL A {
        font-style: italic;
        color: ${themeColor};
    }

    & H2 {
        color: ${themeSecondaryColor};
        margin-top: 1rem;
        margin-left: -1px;
    }

    & P {
        margin-top: 1rem;
    }

    & P:first-child {
        margin-top: 0;
    }
`

export default function Template({ h1, color, children }) {
    useEffect(() => {
        function handleResize() {
            const tiles = [...document.querySelectorAll('.tile')]

            tiles.forEach((t) => t.style.height = null)
    
            const maxHeight = tiles
                .map(t => t.offsetHeight)
                .reduce((a, b) => Math.max(a, b), 0)
            
            tiles.forEach((t) => t.style.height = maxHeight + 'px')    
        }

        handleResize();

        window.addEventListener('resize', handleResize)
        return () => window.removeEventListener('resize', handleResize)
    })

    return <Container>
        <Heading color={color}>{h1}</Heading>

        <PaddingSides>
            <Wrapper>
                <SubpageTiles />
                <DefinedTiles />
            </Wrapper>
        </PaddingSides>

        <Middle color={color}>
            {children}
        </Middle>
    </Container>
}